## a flet icons application

![](https://github.com/modaye/Flet-Icon/raw/master/images/img.png)

⚡ It is a flet-based icon application that categorizes the icons available for flet for easy finding and use.

## Installation
    
    pip install flet_icon

## Usage
at terminal:
    
    fleticon

at python:
```python
import flet
from flet_icon import Application

flet.app(target=Application())

```
